@@ -1,13 +1,29 @@
+( cd opt/kde/lib ; rm -rf libkcmlaptop.so )
+( cd opt/kde/lib ; ln -sf libkcmlaptop.so.0.0.0 libkcmlaptop.so )
 ( cd opt/kde/lib ; rm -rf libksimcore.so )
 ( cd opt/kde/lib ; ln -sf libksimcore.so.1.0.0 libksimcore.so )
+( cd opt/kde/lib ; rm -rf libkmilo.so.1 )
+( cd opt/kde/lib ; ln -sf libkmilo.so.1.0.0 libkmilo.so.1 )
+( cd opt/kde/lib ; rm -rf libkcmlaptop.so.0 )
+( cd opt/kde/lib ; ln -sf libkcmlaptop.so.0.0.0 libkcmlaptop.so.0 )
+( cd opt/kde/lib ; rm -rf libkmilo.so )
+( cd opt/kde/lib ; ln -sf libkmilo.so.1.0.0 libkmilo.so )
+( cd opt/kde/lib ; rm -rf libkregexpeditorcommon.so.1 )
+( cd opt/kde/lib ; ln -sf libkregexpeditorcommon.so.1.0.0 libkregexpeditorcommon.so.1 )
 ( cd opt/kde/lib ; rm -rf libksimcore.so.1 )
 ( cd opt/kde/lib ; ln -sf libksimcore.so.1.0.0 libksimcore.so.1 )
+( cd opt/kde/lib ; rm -rf libkregexpeditorcommon.so )
+( cd opt/kde/lib ; ln -sf libkregexpeditorcommon.so.1.0.0 libkregexpeditorcommon.so )
 ( cd opt/kde/share/doc/HTML/en/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ark ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kgpg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksim ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kfloppy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/khexedit ; rm -rf common )
@@ -18,6 +34,8 @@
 ( cd opt/kde/share/doc/HTML/en/kedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kjots ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kwallet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/powerctrl ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/laptop ; rm -rf common )
@@ -26,6 +44,8 @@
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlowbatwarn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/irkick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcharselect ; rm -rf common )
